# Changelog

## 0.0.2 (2024-03-14)

### Removed

- `YADSL.main_url` property method

## 0.0.3 (2024-03-15)

### Updated

- `example.py` you can now pass the username, and password through command argument.

### Fixed

- `yadsl._adsl.py` some issues.